/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * SoapExternalListener.java - Initial Developper : ofabre
 * -------------------------------------------------------------------------
 */

package org.objectweb.petals.binding.soap.listener.incoming;

import java.util.logging.Level;

import org.objectweb.petals.binding.soap.SoapComponent;
import org.objectweb.petals.component.framework.listener.AbstractExternalListener;

public class SoapExternalListener extends AbstractExternalListener {

    private SoapExternalListenerManager externalListenerManager;

    private String address;

    @Override
    protected void init() {
        this.externalListenerManager = ((SoapComponent) getComponent())
                .getExternalListenerManager();
        this.address = getExtensions().getValue("address");
    }

    /**
     * As there is a single SOAP listener for all incoming soap requests, this
     * method only references the given address. External calls for non
     * registered addresses will be ignored.
     */
    @Override
    protected void start() {
        getLogger().log(Level.FINE, "Starting listening on " + address);
        externalListenerManager.getAddresses().add(address);
    }

    /**
     * unreference the given address. After address removal, it will be
     * impossible to contact service from outside.
     */
    @Override
    protected void stop() {
        getLogger().log(Level.FINE, "Stopping listening on " + address);
        externalListenerManager.getAddresses().remove(address);
    }

}
